;*****************************************************************************/
;*  LibreDWG - free implementation of the DWG file format                    */
;*                                                                           */
;*  Copyright (C) 2011 Free Software Foundation, Inc.                        */
;*  Copyright (C) 2011 Guruprasad Rane                                       */
;*                                                                           */
;*  This library is free software, licensed under the terms of the GNU       */
;*  General Public License as published by the Free Software Foundation,     */
;*  either version 3 of the License, or (at your option) any later version.  */
;*  You should have received a copy of the GNU General Public License        */
;*  along with this program.  If not, see <http://www.gnu.org/licenses/>.    */
;*****************************************************************************/
;*
;*
;* dwgtotxt.lsp Version 0.1 Date:6th November 2011
;* written by Guruprasad Rane <raneguruprasad@gmail.com>
;* Disclaimer : This program is distributed without any warrenty. This program
;* plays with autocad log file so better create a back of logfile before using.
;* Description: Converts visible objects or entities from drawing file to text file.
;* Usage: Load the script in Autocad using Tools>Load application. Run the command
;* dwgtotxt in commandline. New text file with the same name as that of drawingfile
;* will be created. Use txttoxml.py to convert text file to xml.
;* Limitations: Information of only visible objects that can be selected in
;* selection set is exported to text file.


(vl-load-com)
(defun DXOutputtxt (obj)						; Function to output data to text file
	(princ "\n<DwgEntity\n")					; Output text necessary for formatting to xml
	(princ obj)							; Output info about the object
	(setq aaa (vlax-dump-object obj))				; Output info about the object
	(princ " />")							; Output text necessary for formatting to xml

)
(defun C:dwgtotxt ()
  	(setq DXDwgname (getvar "DWGNAME"))				; Get Drawing file name.
  	(setq DXDwgpath (getvar "DWGPREFIX"))				; Get drawing file path.
  	(setq tempX(- (strlen DXDwgname) 4))				; Create Temp varialble for length of file name - 4 (4 is for .dwg)
  	(setq tempName (substr DXDwgname 1 tempX))			; Create Temp varialble without ".dwg"
	(setq DXdwgoutputfile (strcat DXDwgpath tempName ".txt"))	; Create Outputfile path and name
	(setq DXlogfile (getvar 'logfilename))				; Get Autocad Log file path and name
	(setq DXbackupfile (strcat DXlogfile  ".bak"))			; Create Autocad Lof file backup path and name
	(vl-file-delete  DXbackupfile)					; Delete backup file if existing
	(vl-file-copy  DXlogfile DXbackupfile)				; Copy Log file to Backup file
	(vl-file-delete  DXlogfile)					; Delete log file
   	(setq DXsel (ssget "x"))					; Select all objects in the drawing file
	(setq DXi 0)							; Create Temp Coutner variable
  	(setvar 'logfilemode 1)						; Set Logging option to true. New log file gets created here.
	(while (< DXi (sslength DXsel))					; While loop for all objects in selection set
		(setq DXen(ssname DXsel DXi))				; Get Name of object in selection set
		(DXOutputtxt (vlax-ename->vla-object DXen))		; Convert Object name to Object and pass to DXOutputtxt function
	  	(setq DXi(+ DXi 1))					; increase the counter
	)
  	(vl-file-delete  DXdwgoutputfile)				; Delete Text output file is alrady existing
  	(vl-file-copy  DXlogfile DXdwgoutputfile)			; Copy log file to text output file
  	(vl-file-copy  DXbackupfile DXlogfile)				; Copy backup of Log file to Log file.
  	(setvar 'logfilemode 0)						; Set Logginf OFF
)